@@ -8,7 +8,7 @@ use HTTP::Request();
 use JSON::XS();
 use Encode qw(decode_utf8);
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 use constant {
     ONE_REQ     => 1,
@@ -800,7 +800,7 @@ sub _build_cmd {
 }
 
 #===================================
-sub servers { shift->{_servers}{$$} }
+sub servers { shift->{_servers}{$$} || [] }
 #===================================
 
 #===================================
